@@ -15,7 +15,7 @@ use Lemonldap::NG::Common::Apache::Session::Serialize::JSON;
 use Lemonldap::NG::Common::Apache::Session::Store;
 use Lemonldap::NG::Common::Apache::Session::Lock;
 
-our $VERSION = '1.9.3';
+our $VERSION = '1.9.4';
 
 sub _load {
     my ( $backend, $func ) = @_;
@@ -193,10 +193,7 @@ sub _dbiGKFAS {
     my ( $class, $type, $args, $data ) = @_;
     my $next;
     if ( $type !~ /(?:MySQL)/ ) {
-        $next = sub {
-            require MIME::Base64;
-            return thaw( MIME::Base64::decode_base64( $_[0] ) );
-        };
+        $next = \&decodeThaw64;
         if ( $args->{useStorable} ) {
             $args->{unserialize} = $next;
         }
@@ -346,10 +343,10 @@ sub _LDAPGKFAS {
 
     foreach my $entry ( $msg->entries ) {
         my ( $k, $v ) = (
-            $entry->get_value('cn'),
+            $entry->get_value( $args->{ldapAttributeId} ),
             $entry->get_value( $args->{ldapAttributeContent} )
         );
-        eval { $v = decodeThaw64($v); };
+        eval { $v = $args->{unserialize}->( $v, \&decodeThaw64 ); };
         next if ($@);
         if ( ref($data) eq 'CODE' ) {
             $res{$k} = &$data( $v, $k );
@@ -375,7 +372,8 @@ sub _NoSQLGKFAS {
     my %res;
 
     foreach my $k (@keys) {
-        my $v = eval { decodeThaw64( $redis->get($k) ); };
+        my $v =
+          eval { $args->{unserialize}->( $redis->get($k), \&decodeThaw64 ); };
         next if ($@);
         if ( ref($data) eq 'CODE' ) {
             $res{$k} = &$data( $v, $k );
