@@ -5,7 +5,7 @@ use Mouse;
 use JSON;
 use URI::Escape;
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.4';
 
 #       http          ://  server   / path      ? query      # fragment
 # m|(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*)(?:\?([^#]*))?(?:#(.*))?|;
@@ -54,7 +54,8 @@ has REMOTE_USER => (
     is      => 'ro',
     reader  => 'user',
     trigger => sub {
-        $_[0]->{userData} = { _whatToTrace => $_[0]->{REMOTE_USER}, };
+        $_[0]->{userData} = { $Lemonldap::NG::Handler::Main::tsv->{whatTotrace}
+              || _whatToTrace => $_[0]->{REMOTE_USER}, };
     },
 );
 has userData => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
@@ -94,7 +95,6 @@ has body                   => ( is => 'rw', isa    => 'Str', default => '' );
 has CONTENT_TYPE => ( is => 'ro', isa => 'Str', reader => 'contentType', );
 has CONTENT_LENGTH => (
     is      => 'ro',
-    isa     => 'Int',
     reader  => 'contentLength',
     lazy    => 1,
     default => 0,
